@@ -1,5 +1,5 @@
 package Business::PayPal::API;
-$Business::PayPal::API::VERSION = '0.74';
+$Business::PayPal::API::VERSION = '0.75';
 use 5.008001;
 use strict;
 use warnings;
@@ -86,8 +86,15 @@ sub new {
         )
     );
 
-    $Soap{$self} = SOAP::Lite->proxy( $proxy, timeout => $args{timeout} )
-        ->uri(C_xmlns_pp);
+    $Soap{$self} = SOAP::Lite->proxy(
+        $proxy,
+        timeout => $args{timeout},
+        (
+            exists $args{proxy_url}
+            ? ( proxy => [ [ 'http', 'https' ] => $args{proxy_url} ] )
+            : ()
+        )
+    )->uri(C_xmlns_pp);
 
     $Header{$self} = SOAP::Header->name(
         RequesterCredentials => \SOAP::Header->value(
@@ -302,7 +309,7 @@ Business::PayPal::API - PayPal SOAP API client with sandbox support
 
 =head1 VERSION
 
-version 0.74
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -496,6 +503,15 @@ L<https://www.paypal.com/IntegrationCenter/ic_sandbox.html>
 
 =back
 
+=item B<proxy_url>
+
+Optional. When set, the proxy at the specified URL will be used for outbound
+connections.
+
+=item B<timeout>
+
+Optional. Set the timeout in seconds. Defaults to 30 seconds.
+
 =head1 NAME
 
 Business::PayPal::API - PayPal API
@@ -505,7 +521,7 @@ Business::PayPal::API - PayPal API
 Every API call should return an B<Ack> response, whether I<Success>,
 I<Failure>, or otherwise (depending on the API call). If it returns
 any non-success value, you can find an I<Errors> entry in your return
-hash, whose value is a listref of hashrefs:
+hash, whose value is an arrayref of hashrefs:
 
  [ { ErrorCode => 10002,
      LongMessage => "Invalid security header" },
@@ -843,7 +859,7 @@ Bradley M. Kuhn <bkuhn@ebb.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
+This software is copyright (c) 2006-2017 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
